export function bootI18n<T extends Record<string, string>>(
    data: Record<string, T>,
    fallback = document.documentElement.lang || 'en-US'
) {
    const languages = [...navigator.languages, fallback];
    const language = languages.find(language => language in data);
    const words: T = Object.assign(
        {},
        ...languages.reverse().map(name => data[name])
    );
    document.documentElement.lang = language;

    return { language, words };
}

export const CJKV_pattern = /\p{Unified_Ideograph}/u;

export function textJoin(...parts: string[]) {
    return parts
        .map((raw, index) => {
            const isCJKV = CJKV_pattern.test(raw.slice(-1));

            if (index + 1 === parts.length) return raw;

            const diff =
                isCJKV !== CJKV_pattern.test(parts[index + 1]?.trim()[0]);

            return raw + (diff || !isCJKV ? ' ' : '');
        })
        .join('');
}
